@@ -311,7 +311,7 @@ class Project(SquadObject):
     attrs = ['id', 'custom_email_template', 'data_retention_days', 'description',
              'enabled_plugins_list', 'full_name', 'group', 'html_mail', 'important_metadata_keys',
              'is_archived', 'is_public', 'moderate_notifications', 'name', 'notification_timeout',
-             'project_settings', 'slug', 'url', 'wait_before_notification']
+             'slug', 'url', 'wait_before_notification']
 
     def builds(self, count=DEFAULT_COUNT, **filters):
         filters.update({'project': self.id})
@@ -551,6 +551,9 @@ class Test(SquadObject):
     attrs = ['url', 'id', 'name', 'short_name', 'status', 'result', 'test_run', 'log', 'has_known_issues',
              'suite', 'known_issues', 'build', 'environment']
 
+    def __repr__(self):
+        return self.short_name
+
 
 class Suite(SquadObject):
 
@@ -570,12 +573,18 @@ class Suite(SquadObject):
             self.__tests__ = self.__fetch__(Test, filters, count, endpoint=endpoint)
         return self.__tests__
 
+    def __repr__(self):
+        return self.slug
+
 
 class Environment(SquadObject):
 
     endpoint = '/api/environments/'
     attrs = ['url', 'id', 'slug', 'name', 'expected_test_runs', 'description', 'project']
 
+    def __repr__(self):
+        return self.slug
+
 
 class Backend(SquadObject):
 
